@@ -30,12 +30,8 @@ class Compiler(object):
                 if compiler.match_file(input_path):
                     output_path = self.output_path(input_path, compiler.output_extension)
                     infile = finders.find(input_path)
-                    outfile = finders.find(output_path)
-                    if outfile is None:
-                        outfile = self.output_path(infile, compiler.output_extension)
-                        outdated = True
-                    else:
-                        outdated = compiler.is_outdated(input_path, output_path)
+                    outfile = self.output_path(infile, compiler.output_extension)
+                    outdated = compiler.is_outdated(input_path, output_path)
                     try:
                         compiler.compile_file(infile, outfile, outdated=outdated, force=force)
                     except CompilerError:
